const path 	= require('path'),
    koa 	= require('koa'),
    serve	= require('koa-static'),
    metalsmith 	= require('metalsmith'),
    markdown 	= require('metalsmith-markdown'),
    layouts 	= require('metalsmith-layouts'),
    collections	= require('metalsmith-collections'),
    permalinks 	= require('metalsmith-permalinks'),
    beautify 	= require('metalsmith-beautify'),
    feed 	= require('metalsmith-feed'),
    moment 	= require('moment')

const site = {
    author: 'Ev Bogue',
    photo: 'evbogue-badass.jpg',
    title: 'Metalwork',
    url: 'http://evbogue.com/metalwork/',
    port: '3000'
};

const blog = {
    pattern: './*.md',
    reverse: true,
    sortBy: 'date'
};

metalsmith(__dirname)
    .metadata({site})
    .use(markdown())
    .use(collections({blog}))
    .use(permalinks({pattern: ':collections:title'}))
    .use(feed({collection: 'blog'}))
    .use(layouts({engine: 'jade', moment}))
    .use(beautify())
    .destination('./build')
    .build(function(err) {
           if (err) {throw err; }
           console.log('Metalwork is built');
    });


app = koa();

app.use(serve(path.join(__dirname, 'bower')));
app.use(serve(path.join(__dirname, 'build')));
app.listen(site.port);

console.log(`Metalwork is listening at http://localhost:${site.port}/`);

